<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['chunk'] = array(
    'Controllers' => array(
        'skeleton/chunk_c_admin',
        'skeleton/chunk_c_site',
        'skeleton/chunk_c_install',
    ),
    'Models' => array(
        'skeleton/chunk_m_table',
    ),
    'Views' => array(
        'skeleton/chunk_v_site',
    ),
    'Libraries' => array(
        'skeleton/chunk_l_migration',
        'skeleton/chunk_l_pagination',
        'skeleton/chunk_l_form',
    ),
);

$config['crud_callback_chunk'] = array(
    'Input' => array(
        'skeleton/ccc_input',
        'skeleton/ccc_spinner',
        'skeleton/ccc_edit_link',
        'skeleton/ccc_password',
        'skeleton/ccc_select',
        'skeleton/ccc_url',
    ),
    'Text' => array(
        'skeleton/ccc_textarea',
        'skeleton/ccc_texteditor',
    ),
    'Checkbox' => array(
        'skeleton/ccc_active',
    ),
    'Date' => array(
        'skeleton/ccc_date',
        'skeleton/ccc_datetime',
    ),
    'Extra' => array(
        'skeleton/ccc_set_ralation',
        'skeleton/ccc_set_image_upload',
        'skeleton/ccc_multilang',
        'skeleton/ccc_respage',
    ),
    'Price' => array(
        'skeleton/ccc_price_uah',
        'skeleton/ccc_price_usd',
        'skeleton/ccc_price_rub',
    ),
    'KCfinder' => array(
        'skeleton/ccc_kcfinder_file',
        'skeleton/ccc_kcfinder_image',
        'skeleton/ccc_kcfinder_flash',
    ),
);
