<?php
$this->js_css->add_css('/' . $this->config->item('assets_folder') . '/' . $this->config->item('components_folder') . '/ciext/css/menu.css');
?>
<div class="left-menu">
    <ul class="sub-menu">
        <?php foreach ($items as $href => $lang) : ?>
            <li <?php echo ($href == $page) ? 'class="active"' : ''; ?>>
                <a href="<?php echo $href; ?>"><?php echo $lang; ?></a>
            </li>
        <?php endforeach; ?>
    </ul>
</div>