<?php

class ccc_texteditor implements crud_callback_chunk
{
    public function get_name()
    {
        return 'Texteditor';
    }
    
    public function get_options()
    {
        return FALSE;
    }
    
    public function get_schema()
    {
        return 'text';
    }

    public function run()
    {
        return '\'texteditor\'';
    }
}
